========================
django-upstorage-backend
========================

Polls is a Django app to conduct Web-based polls. For each question,
visitors can choose between a fixed number of answers.

Detailed documentation is in the "docs" directory.

Quick start
-----------

1. Add "storages" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'storages',
    ]
